@@ -25,11 +25,12 @@ from pymorphy2.utils import json_write, json_read
 
 logger = logging.getLogger(__name__)
 
-CURRENT_FORMAT_VERSION = '2.2'
+CURRENT_FORMAT_VERSION = '2.4'
 
-LoadedDictionary = collections.namedtuple(
-    'LoadedDictionary',
-    'meta, gramtab, suffixes, paradigms, words, prediction_prefixes, prediction_suffixes_dawgs, Tag, paradigm_prefixes'
+LoadedDictionary = collections.namedtuple('LoadedDictionary', [
+    'meta', 'gramtab', 'suffixes', 'paradigms', 'words',
+    'prediction_prefixes', 'prediction_suffixes_dawgs',
+    'Tag', 'paradigm_prefixes']
 )
 
 
@@ -59,9 +60,7 @@ def load_dict(path, gramtab_format='opencorpora-int'):
     prediction_suffixes_dawgs = []
     for prefix_id in range(len(paradigm_prefixes)):
         fn = _f('prediction-suffixes-%s.dawg' % prefix_id)
-
         assert os.path.exists(fn)
-
         prediction_suffixes_dawgs.append(dawg.PredictionSuffixesDAWG().load(fn))
 
     return LoadedDictionary(meta, gramtab, suffixes, paradigms, words,
@@ -157,15 +156,10 @@ def _load_tag_class(gramtab_format, grammemes_filename):
     if gramtab_format not in tagset.registry:
         raise ValueError("This gramtab format ('%s') is unsupported." % gramtab_format)
 
-    grammemes = json_read(grammemes_filename)
-
-    Tag = tagset.registry[gramtab_format]
-
     # FIXME: clone the class
-    # Tag = type(Tag.__name__, (Tag,), {
-    #     'KNOWN_GRAMMEMES': Tag.KNOWN_GRAMMEMES.copy(),
-    # })
+    Tag = tagset.registry[gramtab_format] #._clone_class()
 
+    grammemes = json_read(grammemes_filename)
     Tag._init_grammemes(grammemes)
 
     return Tag
@@ -173,7 +167,6 @@ def _load_tag_class(gramtab_format, grammemes_filename):
 
 def _load_gramtab(meta, gramtab_format, path):
     """ Load gramtab (a list of tags) """
-
     gramtab_formats = meta.get('gramtab_formats', {})
     if gramtab_format not in gramtab_formats:
         raise ValueError("This gramtab format (%s) is unavailable; available formats: %s" % (gramtab_format, gramtab_formats.keys()))
