@@ -20,6 +20,7 @@ from pymorphy2.utils import word_splits
 
 _cnt_getter = operator.itemgetter(3)
 
+
 class _PrefixAnalyzer(AnalogyAnalizerUnit):
 
     def normalizer(self, form, this_method):
@@ -104,7 +105,6 @@ class UnknownPrefixAnalyzer(_PrefixAnalyzer):
         super(AnalogyAnalizerUnit, self).__init__(morph)
         self.dict_analyzer = DictionaryAnalyzer(morph)
 
-
     def parse(self, word, word_lower, seen_parses):
         result = []
         for prefix, unprefixed_word in word_splits(word_lower):
@@ -118,11 +118,11 @@ class UnknownPrefixAnalyzer(_PrefixAnalyzer):
                     continue
 
                 parse = (
-                    prefix+fixed_word,
+                    prefix + fixed_word,
                     tag,
-                    prefix+normal_form,
-                    score*self.ESTIMATE_DECAY,
-                    methods_stack+(method,)
+                    prefix + normal_form,
+                    score * self.ESTIMATE_DECAY,
+                    methods_stack + (method,)
                 )
                 add_parse_if_not_seen(parse, result, seen_parses)
 
@@ -153,13 +153,13 @@ class KnownSuffixAnalyzer(AnalogyAnalizerUnit):
     """
 
     terminal = False
+    min_word_length = 4
     ESTIMATE_DECAY = 0.5
 
     class FakeDictionary(DictionaryAnalyzer):
         """ This is just a DictionaryAnalyzer with different __repr__ """
         pass
 
-
     def __init__(self, morph):
         super(KnownSuffixAnalyzer, self).__init__(morph)
 
@@ -169,9 +169,10 @@ class KnownSuffixAnalyzer(AnalogyAnalizerUnit):
 
         self.fake_dict = self.FakeDictionary(morph)
 
-
     def parse(self, word, word_lower, seen_parses):
         result = []
+        if len(word) < self.min_word_length:
+            return result
 
         # smoothing; XXX: isn't max_cnt better?
         # or maybe use a proper discounting?
@@ -195,6 +196,7 @@ class KnownSuffixAnalyzer(AnalogyAnalizerUnit):
                         # skip non-productive tags
                         if not tag.is_productive():
                             continue
+
                         total_counts[prefix_id] += cnt
 
                         # avoid duplicate parses
@@ -222,12 +224,14 @@ class KnownSuffixAnalyzer(AnalogyAnalizerUnit):
         result.sort(key=_cnt_getter, reverse=True)
         return result
 
-
     def tag(self, word, word_lower, seen_tags):
         # XXX: the result order may be different from
         # ``self.parse(...)``.
 
         result = []
+        if len(word) < self.min_word_length:
+            return result
+
         for prefix_id, prefix, suffixes_dawg in self._possible_prefixes(word_lower):
 
             for i in self._prediction_splits:
