@@ -9,15 +9,19 @@ from __future__ import absolute_import, unicode_literals, division
 from pymorphy2.units.base import BaseAnalyzerUnit
 from pymorphy2.shapes import is_latin, is_punctuation, is_roman_number
 
+
 class _ShapeAnalyzer(BaseAnalyzerUnit):
 
     terminal = True
     SCORE = 0.9
     EXTRA_GRAMMEMES = []
+    EXTRA_GRAMMEMES_CYR = []
 
     def __init__(self, morph):
         super(_ShapeAnalyzer, self).__init__(morph)
-        self.morph.TagClass.KNOWN_GRAMMEMES.update(self.EXTRA_GRAMMEMES)
+
+        for lat, cyr in zip(self.EXTRA_GRAMMEMES, self.EXTRA_GRAMMEMES_CYR):
+            self.morph.TagClass.add_grammemes_to_known(lat, cyr)
 
     def parse(self, word, word_lower, seen_parses):
         shape = self.check_shape(word, word_lower)
@@ -49,10 +53,13 @@ class _ShapeAnalyzer(BaseAnalyzerUnit):
 
 class _SingleShapeAnalyzer(_ShapeAnalyzer):
     TAG_STR = None
+    TAG_STR_CYR = None
 
     def __init__(self, morph):
         assert self.TAG_STR is not None
+        assert self.TAG_STR_CYR is not None
         self.EXTRA_GRAMMEMES = self.TAG_STR.split(',')
+        self.EXTRA_GRAMMEMES_CYR = self.TAG_STR_CYR.split(',')
         super(_SingleShapeAnalyzer, self).__init__(morph)
         self._tag = self.morph.TagClass(self.TAG_STR)
 
@@ -66,6 +73,7 @@ class PunctuationAnalyzer(_SingleShapeAnalyzer):
     Example: "," -> PNCT
     """
     TAG_STR = 'PNCT'
+    TAG_STR_CYR = 'ЗПР'  # aot.ru uses this name
 
     def check_shape(self, word, word_lower):
         return is_punctuation(word)
@@ -77,29 +85,51 @@ class LatinAnalyzer(_SingleShapeAnalyzer):
     Example: "pdf" -> LATN
     """
     TAG_STR = 'LATN'
+    TAG_STR_CYR = 'ЛАТ'
 
     def check_shape(self, word, word_lower):
         return is_latin(word)
 
 
-class NumberAnalyzer(_SingleShapeAnalyzer):
+class NumberAnalyzer(_ShapeAnalyzer):
     """
-    This analyzer marks numbers with "NUMB" tag.
-    Example: "12" -> NUMB
+    This analyzer marks integer numbers with "NUMB,int" or "NUMB,real" tags.
+    Example: "12" -> NUMB,int; "12.4" -> NUMB,real
 
     .. note::
 
         Don't confuse it with "NUMR": "тридцать" -> NUMR
 
     """
-    TAG_STR = 'NUMB'
+    EXTRA_GRAMMEMES = ['NUMB', 'intg', 'real']
+    EXTRA_GRAMMEMES_CYR = ['ЧИСЛО', 'цел', 'вещ']
+
+    def __init__(self, morph):
+        super(NumberAnalyzer, self).__init__(morph)
+        self._tags = {
+            'intg': morph.TagClass('NUMB,intg'),
+            'real': morph.TagClass('NUMB,real'),
+        }
 
     def check_shape(self, word, word_lower):
-        return word.isdigit()
+        try:
+            int(word)
+            return 'intg'
+        except ValueError:
+            try:
+                float(word.replace(',', '.'))
+                return 'real'
+            except ValueError:
+                pass
+        return False
+
+    def get_tag(self, word, shape):
+        return self._tags[shape]
 
 
 class RomanNumberAnalyzer(_SingleShapeAnalyzer):
     TAG_STR = 'ROMN'
+    TAG_STR_CYR = 'РИМ'
     terminal = False  # give LatinAnalyzer a chance
 
     def check_shape(self, word, word_lower):
